[![Build Status](https://travis-ci.org/suguby/astrobox.svg?branch=master)](https://travis-ci.org/suguby/astrobox)

### AstroBox

AstroBox game for programmers.

![screenshot one](screenshots/game_begin.png "Game Begin")​